@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-06-07 22:28:00 -0700 (Thu, 07 Jun 2007) $
-# $Revision: 101 $
+# $Date: 2007-06-22 19:17:36 -0700 (Fri, 22 Jun 2007) $
+# $Revision: 116 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -9,7 +9,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.3');
+use version; our $VERSION = qv('0.3.4');
 
 sub base { return shift->{'base'}; }
 
@@ -59,7 +59,7 @@ sub in_fb_canvas {
 sub in_frame {
     my ( $self, $q ) = @_;
     my $fb_params = $self->get_fb_params($q);
-    return 1 if $fb_params->{'in_canvas'} or $fb_params->{'in_frame'};
+    return 1 if $fb_params->{'in_canvas'} or $fb_params->{'in_iframe'};
     return;
 }
 
@@ -72,7 +72,7 @@ WWW::Facebook::API::Canvas - Facebook Canvas
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Canvas version 0.3.3
+This document describes WWW::Facebook::API::Canvas version 0.3.4
 
 =head1 SYNOPSIS
 
@@ -125,9 +125,9 @@ Return true if inside a canvas (See L<DESCRIPTION>):
 
 =item in_frame( $q )
 
-Return true if inside a frame or canvas (See L<DESCRIPTION>):
+Return true if inside an iframe or canvas (See L<DESCRIPTION>):
 
-    $response = $client->canvas->in_fb_canvas( $q )
+    $response = $client->canvas->in_frame( $q )
 
 =item validate_sig( $q )
 
